/*
 * dblink.h
 *
 * Functions returning results from a remote database
 *
 * Joe Conway <mail@joeconway.com>
 *
 * Copyright (c) 2001, 2002 by PostgreSQL Global Development Group
 * ALL RIGHTS RESERVED;
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without a written agreement
 * is hereby granted, provided that the above copyright notice and this
 * paragraph and the following two paragraphs appear in all copies.
 *
 * IN NO EVENT SHALL THE AUTHOR OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
 * LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS
 * DOCUMENTATION, EVEN IF THE AUTHOR OR DISTRIBUTORS HAVE BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * THE AUTHOR AND DISTRIBUTORS SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND THE AUTHOR AND DISTRIBUTORS HAS NO OBLIGATIONS TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 *
 */

#ifndef DBLINK_H
#define DBLINK_H

/*
 * This struct holds the results of the remote query.
 * Use fn_extra to hold a pointer to it across calls
 */
typedef struct
{
	/*
	 * last tuple number accessed
	 */
	int			tup_num;

	/*
	 * resource index number for this context
	 */
	int			res_id_index;

	/*
	 * the actual query results
	 */
	PGresult   *res;
}	dblink_results;

/*
 * This struct information about public connections
 */
typedef struct
{
	/*
	 * resource index number for this context
	 */
	int			conn_id_index;

	/*
	 * the actual connection pointer
	 */
	PGconn   *conn;
}	public_pq_connections;


typedef struct
{
	/*
	 * resource index number for this context
	 */
	int			res_id_index;

	/*
	 * the actual query results
	 */
	PGresult   *res;
}	public_pq_results;

/*
 * External declarations
 */
/* deprecated */
extern Datum dblink(PG_FUNCTION_ARGS);
extern Datum dblink_tok(PG_FUNCTION_ARGS);

/* supported */
extern Datum dblink_connect(PG_FUNCTION_ARGS);
extern Datum dblink_disconnect(PG_FUNCTION_ARGS);
extern Datum dblink_open(PG_FUNCTION_ARGS);
extern Datum dblink_close(PG_FUNCTION_ARGS);
extern Datum dblink_fetch(PG_FUNCTION_ARGS);
extern Datum dblink_record(PG_FUNCTION_ARGS);
extern Datum dblink_exec(PG_FUNCTION_ARGS);
extern Datum dblink_get_pkey(PG_FUNCTION_ARGS);
extern Datum dblink_last_oid(PG_FUNCTION_ARGS);
extern Datum dblink_build_sql_insert(PG_FUNCTION_ARGS);
extern Datum dblink_build_sql_delete(PG_FUNCTION_ARGS);
extern Datum dblink_build_sql_update(PG_FUNCTION_ARGS);
extern Datum dblink_current_query(PG_FUNCTION_ARGS);

extern char *debug_query_string;

extern Datum dblink_pq_Connectdb(PG_FUNCTION_ARGS);
extern Datum dblink_pq_SetdbLogin(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Status(PG_FUNCTION_ARGS);
extern Datum dblink_pq_StatusStr(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Finish(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Reset(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Db(PG_FUNCTION_ARGS);
extern Datum dblink_pq_User(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Password(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Host(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Port(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Tty(PG_FUNCTION_ARGS);
extern Datum dblink_pq_ErrorMessage(PG_FUNCTION_ARGS);
extern Datum dblink_pq_BackendPID(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Exec(PG_FUNCTION_ARGS);
extern Datum dblink_pq_ResultStatus(PG_FUNCTION_ARGS);
extern Datum dblink_pq_ResStatus(PG_FUNCTION_ARGS);
extern Datum dblink_pq_ResultErrorMessage(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Clear(PG_FUNCTION_ARGS);
extern Datum dblink_pq_EscapeString(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Ntuples(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Nfields(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Fname(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Fnumber(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Ftype(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Fmod(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Fsize(PG_FUNCTION_ARGS);
extern Datum dblink_pq_BinaryTuples(PG_FUNCTION_ARGS);
extern Datum dblink_pq_GetValue(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Getisnull(PG_FUNCTION_ARGS);
extern Datum dblink_pq_Getlength(PG_FUNCTION_ARGS);
extern Datum dblink_pq_CmdStatus(PG_FUNCTION_ARGS);
extern Datum dblink_pq_CmdTuples(PG_FUNCTION_ARGS);
extern Datum dblink_pq_OidValue(PG_FUNCTION_ARGS);
extern Datum dblink_pq_OidStatus(PG_FUNCTION_ARGS);

#endif   /* DBLINK_H */
